bool loadConfig() {                                                // Завантаження даних збереженних в файлі config.json
  File configFile = SPIFFS.open("/config.json", "r");              // Відкриваемо файл на читання
  if(!configFile) {                                                // якщо файл не знайдено ствоюємого його та записуємо в ньго данні з наших змінних
    if(printCom) Serial.println("Failed to open config file");
    saveConfig();                                                  // Створюємо файл
    configFile.close();
    return false;                                                  // Повернення з помилкою
  }
  size_t size = configFile.size();                                 // Перевіряємо ромір файлу, будемо використовувати файл довжиною в 1024 байта
  if(size > 8192) {
    if(printCom) Serial.println("Config file size is too large");
    configFile.close();
    return false;                                                  // Повернення з помилкою
  }
  jsonConfig = configFile.readString();                            // завантажуємо файл конфігурації в глобальну змінну
  DynamicJsonDocument doc(8192);                                    // Резервуємо память для json обекту буфер може розти по мірі необхідності переважно для ESP8266 
  deserializeJson(doc, jsonConfig);
  configFile.close();
  ssidAP = doc["ssidAP"].as<String>();
  passwordAP = doc["passwordAP"].as<String>();                     // Так отримуємо рядок
  ssid = doc["ssid"].as<String>();
  password = doc["password"].as<String>();
  ntpServerName = doc["ntpServerName"].as<String>();
  timeZone = doc["timeZone"];                                     // Так отримуємо число
  isDayLightSaving = doc["isDayLightSaving"];
  kuOn = doc["kuOn"];
  kuOff = doc["kuOff"];
  weatherHost = doc["weatherHost"];
  weatherKey0 = doc["weatherKey0"].as<String>();
  weatherKey1 = doc["weatherKey1"].as<String>();
  cityID0 = doc["cityID0"].as<String>();
  cityID1 = doc["cityID1"].as<String>();
  weatherLang = doc["weatherLang"].as<String>();
  outForecast = doc["outForecast"];
  outForecastNow = doc["outForecastNow"];
  outForecastTomorrow = doc["outForecastTomorrow"];
  show_wind_dirZ = doc["show_wind_dirZ"];
  show_rhZ = doc["show_rhZ"];
  show_descZ = doc["show_descZ"];
  show_wind_dir = doc["show_wind_dir"];
  show_rh = doc["show_rh"];
  show_desc = doc["show_desc"];
  show_desc0 = doc["show_desc0"];
  show_ps = doc["show_ps"];
  show_cl = doc["show_cl"];
  show_clZ = doc["show_clZ"];
  timeScrollStart = doc["timeScrollStart"];
  timeScrollStop = doc["timeScrollStop"];
  timeScrollSpeed = doc["timeScrollSpeed"];
  rotate = doc["rotate"];
  updateOTA = doc["updateOTA"];
  volBrightnessD = doc["volBrightnessD"];
  volBrightnessN = doc["volBrightnessN"];
  timeDay = doc["timeDay"];
  timeNight = doc["timeNight"];
  volBrightnessAuto = doc["volBrightnessAuto"];
  clockNight = doc["clockNight"];
  buzzerSet = doc["buzzerSet"];
  buzzer = doc["buzzer"];
  showsens = doc["showsens"];
  showdate = doc["showdate"];
  showdate1 = doc["showdate1"];
  showdate0 = doc["showdate0"];
  showdate2 = doc["showdate2"];
  showdate3 = doc["showdate3"]; 
  flash1 = doc["flash1"];
  flash2 = doc["flash2"];
  sensd = doc["sensd"];
  sensu = doc["sensu"];
  sensh = doc["sensh"];
  sensp = doc["sensp"];
  mqttOn = doc["mqttOn"];
  snprintf(mqtt_server, 24, "%s", (doc["mqtt_server"].as<String>()).c_str());
  mqtt_port = doc["mqtt_port"];
  snprintf(mqtt_user, 24, "%s", (doc["mqtt_user"].as<String>()).c_str());
  snprintf(mqtt_pass, 24, "%s", (doc["mqtt_pass"].as<String>()).c_str());
  snprintf(mqtt_name, 24, "%s", (doc["mqtt_name"].as<String>()).c_str());
  snprintf(mqtt_pub_temp, 24, "%s", (doc["mqtt_pub_temp"].as<String>()).c_str());
  snprintf(mqtt_pub_tempUl, 24, "%s", (doc["mqtt_pub_tempUl"].as<String>()).c_str());
  snprintf(mqtt_pub_hum, 24, "%s", (doc["mqtt_pub_hum"].as<String>()).c_str());
  snprintf(mqtt_pub_press, 24, "%s", (doc["mqtt_pub_press"].as<String>()).c_str());
  snprintf(mqtt_pub_alt, 24, "%s", (doc["mqtt_pub_alt"].as<String>()).c_str());
  snprintf(mqtt_sub, 24, "%s", (doc["mqtt_sub"].as<String>()).c_str());
  snprintf(mqtt_sub_inform, 24, "%s", (doc["mqtt_sub_inform"].as<String>()).c_str());
  printCom = doc["printCom"];
  sensorDom = doc["sensorDom"];
  sensorUl = doc["sensorUl"];
  sensorHumi = doc["sensorHumi"];
  sensorPrAl = doc["sensorPrAl"];
  lang = doc["lang"];
  alarme[0][0] = doc["al_0_0"];
  alarme[0][1] = doc["al_0_1"];
  alarme[0][2] = doc["al_0_2"];
  alarme[1][0] = doc["al_1_0"];
  alarme[1][1] = doc["al_1_1"];
  alarme[1][2] = doc["al_1_2"];
  alarme[2][0] = doc["al_2_0"];
  alarme[2][1] = doc["al_2_1"];
  alarme[2][2] = doc["al_2_2"];
  alarme[3][0] = doc["al_3_0"];
  alarme[3][1] = doc["al_3_1"];
  alarme[3][2] = doc["al_3_2"];
  alarme[4][0] = doc["al_4_0"];
  alarme[4][1] = doc["al_4_1"];
  alarme[4][2] = doc["al_4_2"];
  memory_date[0][0] = doc["md_0_0"];
  memory_date[0][1] = doc["md_0_1"];
  memory_date[1][0] = doc["md_1_0"];
  memory_date[1][1] = doc["md_1_1"];
  memory_date[2][0] = doc["md_2_0"];
  memory_date[2][1] = doc["md_2_1"];
  memory_date[3][0] = doc["md_3_0"];
  memory_date[3][1] = doc["md_3_1"];
  memory_date[4][0] = doc["md_4_0"];
  memory_date[4][1] = doc["md_4_1"];
  memory_date[5][0] = doc["md_5_0"];
  memory_date[5][1] = doc["md_5_1"];
  memory_date[6][0] = doc["md_6_0"];
  memory_date[6][1] = doc["md_6_1"];
  memory_date[7][0] = doc["md_7_0"];
  memory_date[7][1] = doc["md_7_1"];
  memory_date[8][0] = doc["md_8_0"];
  memory_date[8][1] = doc["md_8_1"];
  snprintf(memory_date_mes0, 51, "%s", (doc["md_0_2"].as<String>()).c_str());
  snprintf(memory_date_mes1, 51, "%s", (doc["md_1_2"].as<String>()).c_str());
  snprintf(memory_date_mes2, 51, "%s", (doc["md_2_2"].as<String>()).c_str());
  snprintf(memory_date_mes3, 51, "%s", (doc["md_3_2"].as<String>()).c_str());
  snprintf(memory_date_mes4, 51, "%s", (doc["md_4_2"].as<String>()).c_str());
  snprintf(memory_date_mes5, 51, "%s", (doc["md_5_2"].as<String>()).c_str());
  snprintf(memory_date_mes6, 51, "%s", (doc["md_6_2"].as<String>()).c_str());
  snprintf(memory_date_mes7, 51, "%s", (doc["md_7_2"].as<String>()).c_str());
  snprintf(memory_date_mes8, 51, "%s", (doc["md_8_2"].as<String>()).c_str());
  memory_hour_start = doc["memory_hour_start"];
  memory_hour_end = doc["memory_hour_end"];
  fontCLOCK = doc["fontCLOCK"];
  aliData = doc["aliData"];
  corrTempD = doc["corrTempD"];
  corrTempU = doc["corrTempU"];
  corrHumi  = doc["corrHumi"];
  corrPress = doc["corrPress"];
  NUM_MAX = doc["NUM_MAX"];
  rtcStat = doc["rtcStat"];
  uuid  = doc["uuid"].as<String>();
  api_key = doc["api_key"].as<String>();
  sensors_ID0 = doc["sensors_ID0"];
  sensors_ID1 = doc["sensors_ID1"];
  sensors_ID2 = doc["sensors_ID2"];
  if(printCom) {
    printTime();
    Serial.print("Load Config : ");
    Serial.println(jsonConfig);
  }
  return true;
}
//=================================================================
bool saveConfig() {
  DynamicJsonDocument doc(8192);
  deserializeJson(doc, jsonConfig);
  doc["ssidAP"] = ssidAP;
  doc["passwordAP"] = passwordAP;
  doc["ssid"] = ssid;
  doc["password"] = password;
  doc["ntpServerName"] = ntpServerName;
  doc["timeZone"] = timeZone;
  doc["isDayLightSaving"] = isDayLightSaving;
  doc["kuOn"] = kuOn;
  doc["kuOff"] = kuOff;
  doc["weatherHost"] = weatherHost;
  doc["weatherKey0"] = weatherKey0;
  doc["weatherKey1"] = weatherKey1;
  doc["cityID0"] = cityID0;
  doc["cityID1"] = cityID1;
  doc["weatherLang"] = weatherLang;
  doc["outForecast"] = outForecast;
  doc["outForecastNow"] = outForecastNow;
  doc["outForecastTomorrow"] = outForecastTomorrow;
  doc["show_wind_dirZ"] = show_wind_dirZ;
  doc["show_rhZ"] = show_rhZ;
  doc["show_descZ"] = show_descZ;
  doc["show_wind_dir"] = show_wind_dir;
  doc["show_rh"] = show_rh;
  doc["show_desc"] = show_desc;
  doc["show_desc0"] = show_desc0;
  doc["show_ps"] = show_ps;
  doc["show_cl"] = show_cl;
  doc["show_clZ"] = show_clZ;
  doc["timeScrollStart"] = timeScrollStart;
  doc["timeScrollStop"] = timeScrollStop;
  doc["timeScrollSpeed"] = timeScrollSpeed;
  doc["rotate"] = rotate;
  doc["updateOTA"] = updateOTA;
  doc["volBrightnessD"] = volBrightnessD;
  doc["volBrightnessN"] = volBrightnessN;
  doc["timeDay"] = timeDay;
  doc["timeNight"] = timeNight;
  doc["volBrightnessAuto"] = volBrightnessAuto;
  doc["clockNight"] = clockNight;
  doc["buzzerSet"] = buzzerSet;
  doc["buzzer"] = buzzer;
  doc["showsens"] = showsens;
  doc["showdate"] = showdate;
  doc["showdate1"] = showdate1;
  doc["showdate0"] = showdate0;
  doc["showdate2"] = showdate2;
  doc["showdate3"] = showdate3;
  doc["flash1"] = flash1;
  doc["flash2"] = flash2;
  doc["sensd"] = sensd;
  doc["sensu"] = sensu;
  doc["sensh"] = sensh;
  doc["sensp"] = sensp;
  doc["mqttOn"] = mqttOn;
  doc["mqtt_server"] = mqtt_server;
  doc["mqtt_port"] = mqtt_port;
  doc["mqtt_user"] = mqtt_user;
  doc["mqtt_pass"] = mqtt_pass;
  doc["mqtt_name"] = mqtt_name;
  doc["mqtt_pub_temp"] = mqtt_pub_temp;
  doc["mqtt_pub_tempUl"] = mqtt_pub_tempUl;
  doc["mqtt_pub_hum"] = mqtt_pub_hum;
  doc["mqtt_pub_press"] = mqtt_pub_press;
  doc["mqtt_pub_alt"] = mqtt_pub_alt;
  doc["mqtt_sub"] = mqtt_sub;
  doc["mqtt_sub_inform"] = mqtt_sub_inform;
  doc["printCom"] = printCom;
  doc["sensorDom"] = sensorDom;
  doc["sensorUl"] = sensorUl;
  doc["sensorHumi"] = sensorHumi;
  doc["sensorPrAl"] = sensorPrAl;
  doc["lang"] = lang;
  doc["al_0_0"] = alarme[0][0];
  doc["al_0_1"] = alarme[0][1];
  doc["al_0_2"] = alarme[0][2];
  doc["al_1_0"] = alarme[1][0];
  doc["al_1_1"] = alarme[1][1];
  doc["al_1_2"] = alarme[1][2];
  doc["al_2_0"] = alarme[2][0];
  doc["al_2_1"] = alarme[2][1];
  doc["al_2_2"] = alarme[2][2];
  doc["al_3_0"] = alarme[3][0];
  doc["al_3_1"] = alarme[3][1];
  doc["al_3_2"] = alarme[3][2];
  doc["al_4_0"] = alarme[4][0];
  doc["al_4_1"] = alarme[4][1];
  doc["al_4_2"] = alarme[4][2];
  doc["md_0_0"] = memory_date[0][0];
  doc["md_0_1"] = memory_date[0][1];
  doc["md_1_0"] = memory_date[1][0];
  doc["md_1_1"] = memory_date[1][1];
  doc["md_2_0"] = memory_date[2][0];
  doc["md_2_1"] = memory_date[2][1];
  doc["md_3_0"] = memory_date[3][0];
  doc["md_3_1"] = memory_date[3][1];
  doc["md_4_0"] = memory_date[4][0];
  doc["md_4_1"] = memory_date[4][1];
  doc["md_5_0"] = memory_date[5][0];
  doc["md_5_1"] = memory_date[5][1];
  doc["md_6_0"] = memory_date[6][0];
  doc["md_6_1"] = memory_date[6][1];
  doc["md_7_0"] = memory_date[7][0];
  doc["md_7_1"] = memory_date[7][1];
  doc["md_8_0"] = memory_date[8][0];
  doc["md_8_1"] = memory_date[8][1];
  doc["md_0_2"] = memory_date_mes0;
  doc["md_1_2"] = memory_date_mes1;
  doc["md_2_2"] = memory_date_mes2;
  doc["md_3_2"] = memory_date_mes3;
  doc["md_4_2"] = memory_date_mes4;
  doc["md_5_2"] = memory_date_mes5;
  doc["md_6_2"] = memory_date_mes6;
  doc["md_7_2"] = memory_date_mes7;
  doc["md_8_2"] = memory_date_mes8;
  doc["memory_hour_start"] = memory_hour_start;
  doc["memory_hour_end"] = memory_hour_end;
  doc["fontCLOCK"] = fontCLOCK;
  doc["aliData"] = aliData;
  doc["corrTempD"] = corrTempD;
  doc["corrTempU"] = corrTempU;
  doc["corrHumi"] = corrHumi;
  doc["corrPress"] = corrPress;
  doc["NUM_MAX"] = NUM_MAX;
  doc["rtcStat"] = rtcStat;
  doc["uuid"] = uuid;
  doc["api_key"] = api_key;
  doc["sensors_ID0"] = sensors_ID0;
  doc["sensors_ID1"] = sensors_ID1;
  doc["sensors_ID2"] = sensors_ID2;
  jsonConfig = "";
  if(serializeJson(doc, jsonConfig)==0){
    Serial.println(F("Failed to write to jsonConfig"));
  }  
  File configFile = SPIFFS.open("/config.json", "w");                // Відкриваємо файл для запису
  if(!configFile) {
    configFile.close();
    return false;
  }
  if(serializeJson(doc, configFile)==0){
    Serial.println(F("Failed to write to file"));
  } 
  if(printCom) {
    printTime();
    Serial.print("Save Config : ");
    Serial.println(jsonConfig);
  }
  configFile.close();
  bip();
  return true;
}
